.. _sec-command-line-options:

======================
 Command Line Options
======================

.. sphinx_argparse_cli::
   :module: ford
   :func: get_command_line_arguments
   :hook:
   :no_default_values:
   :prog: ford
   :usage_width: 80
